==> JQueryTools-1.2.tar.gz: JQueryTools/lang/en_US.php <==
<?php
#A


#B


#C

#D


#E


#F
$lang['friendlyname'] = 'JQuery Toolbox';


#G


#H


#I


#J


#K


#L


#M
$lang['moddescription'] = 'A toolbox of Jquery utilities to aide in creating dynamic and fancy CMS Made Simple modules and websites';

#N


#O


#P
$lang['param_action'] = 'Specify the action to be called.  Possible values are:<ul><li>require - Marks the selected libraries to be included in the page HTML.  See the list above for the list of available libraries.</li><li>placemarker - Indicates the place in the HTML output where the selected libraries should be included.</li><li>incjs - <em>(deprecated)</em> Include required javascript files.</li><li>ready - <em>(deprecated)</em> Output default ready function.</li></ul>';
$lang['param_exclude'] = 'Applicable only to the placemarker and incjs actions, this parameter allows excluding certain jquery plugins from the output generated.  Possible values are: tablesorter,cluetip,form.';
$lang['param_lib'] = 'Applicable only to the require action, this parameter allows specifying a comma separated list of jquery libraries to install.';
$lang['param_no_css'] = 'Applicable only to the placemarker and incjs actions, this will exclude css tags from being output';
$lang['param_no_cdn'] = 'Applicable only to the placemarker and incjs actions, this will prevent JQueryTools from using a CDN URL for the javascript libraries, if one is available (not all libraries are available by a CDN';
$lang['param_no_js'] = 'Applicable only to the placemarker and incjs actions, this will exclude script tags from being output';
$lang['param_no_jquery'] = 'Applicable only to the placemarker and incjs actions, this will exclude jquery from being included';
$lang['postinstall'] = 'The JQueryTools module has been installed.... get crackin';
$lang['postuninstall'] = 'The JQueryTools module has been uninstalled';
$lang['preuninstall'] = 'Removing this module could damage the appearance and functionality of your website.  Are you sure you want to continue?';

#Q


#R


#S


#T


#U


#V


#W


#X


#Y


#Z


?>

==> JQueryTools-1.2.5.tar.gz: JQueryTools/lang/en_US.php <==
<?php
#A


#B


#C

#D


#E


#F
$lang['friendlyname'] = 'JQuery Toolbox';


#G


#H


#I


#J


#K


#L


#M
$lang['moddescription'] = 'A toolbox of Jquery utilities to aide in creating dynamic and fancy CMS Made Simple modules and websites';

#N


#O


#P
$lang['param_action'] = 'Specify the action to be called.  Possible values are:<ul><li>require - Marks the selected libraries to be included in the page HTML.  See the list above for the list of available libraries.</li><li>placemarker - Indicates the place in the HTML output where the selected libraries should be included.</li><li>incjs - <em>(deprecated)</em> Include required javascript files.</li><li>ready - <em>(deprecated)</em> Output default ready function.</li></ul>';
$lang['param_exclude'] = 'Applicable only to the placemarker and incjs actions, this parameter allows excluding certain jquery plugins from the output generated.  Possible values are: tablesorter,cluetip,form.';
$lang['param_lib'] = 'Applicable only to the require action, this parameter allows specifying a comma separated list of jquery libraries to install.';
$lang['param_no_css'] = 'Applicable only to the placemarker and incjs actions, this will exclude css tags from being output';
$lang['param_no_cdn'] = 'Applicable only to the placemarker and incjs actions, this will prevent JQueryTools from using a CDN URL for the javascript libraries, if one is available (not all libraries are available by a CDN';
$lang['param_no_js'] = 'Applicable only to the placemarker and incjs actions, this will exclude script tags from being output';
$lang['param_no_jquery'] = 'Applicable only to the placemarker and incjs actions, this will exclude jquery from being included';
$lang['param_no_ready'] = 'Applicable only to the placemarker actions, this will exclude any ready functions from being output.';
$lang['postinstall'] = 'The JQueryTools module has been installed.... get crackin';
$lang['postuninstall'] = 'The JQueryTools module has been uninstalled';
$lang['preuninstall'] = 'Removing this module could damage the appearance and functionality of your website.  Are you sure you want to continue?';

#Q


#R


#S


#T


#U


#V


#W


#X


#Y


#Z


?>
